Module: Departure::Migration::ClassMethods
- Defined in:
- lib/departure/migration.rb
Instance Method Summary collapse
-
#disable_departure! ⇒ Object
Declare ‘disable_departure!` in the class body of your migration to disable Departure for that migration only (when Departure.configuration.enabled_by_default is true, the default).
-
#uses_departure! ⇒ Object
Declare ‘uses_departure!` in the class body of your migration to enable Departure for that migration only when Departure.configuration.enabled_by_default is false.
Instance Method Details
#disable_departure! ⇒ Object
Declare ‘disable_departure!` in the class body of your migration to disable Departure for that migration only (when Departure.configuration.enabled_by_default is true, the default).
38 39 40 |
# File 'lib/departure/migration.rb', line 38 def disable_departure! self.uses_departure = false end |
#uses_departure! ⇒ Object
Declare ‘uses_departure!` in the class body of your migration to enable Departure for that migration only when Departure.configuration.enabled_by_default is false.
31 32 33 |
# File 'lib/departure/migration.rb', line 31 def uses_departure! self.uses_departure = true end |